@@ -16,27 +16,62 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# # Pryngles module: Constants
-
-# This module contains the definitions of useful constants.
-
-# ## Pryngles
+# # Pryngles module: Constants and Enumerators
+# 
+# This module contains all the constants required by other modules in the package.
 
 from pryngles import *
 
+# ## External modules
+
+import numpy as np
+from rebound import units
+import re
+
+# ## Constants and enumerators by Module
+
+# ### System related
+
+import os
+#Root directory
+try:
+    FILE=__file__
+    ROOTDIR=os.path.abspath(os.path.dirname(FILE))
+except:
+    import IPython
+    FILE=""
+    ROOTDIR=os.path.abspath('')
+    
+IN_JUPYTER='ipykernel' in sys.modules
+
+# ### Body related
+
+BODY_KINDS=[]
+
+# ### Spangle related
+
+#ENUMERATOR: Type of spangle
+SOLID_SPANGLE=0
+GRANULAR_SPANGLE=1
+ATMOSPHERIC_SPANGLE=2
+
+#ENUMERATOR: Reference system
+EQU=0
+ECL=1
+
 # ## Constants class
+# 
+# This class contains several physical and astronomical constants.  It takes constants from other packages (rebound, astropy) and define other constants based on reliable sources.
 
 class Consts(object):pass
-    
+
 #Mathematical constants
-import numpy as np
 Consts.rad=180/np.pi
 Consts.deg=1/Consts.rad
-Consts.ppm=1e6 #parts per million
-Consts.ppb=1e9 #parts per billion
+Consts.ppm=1e6 #parts per million factor
+Consts.ppb=1e9 #parts per billion factor
 
 #Physical constants
-from rebound import units
 GSI=units.convert_G(["m","s","kg"]) # G constant in SI units
 for const in "times","lengths","masses":
     values=eval(f"units.{const}_SI.copy()")
@@ -44,9 +79,13 @@ for const in "times","lengths","masses":
         exec(f"Consts.{key}=values[key]")
 
 #Size of reference objects
-Consts.rearth=6378.137e3 #m, volumetric mean radius
-Consts.rsun=695700e3 #m, nominal solar radius
-Consts.rjupiter=71492e3 #m, equatorial radius
-Consts.rsaturn=60268e3 #m
+Consts.rearth=6378.137e3 #m, volumetric mean radius, source: 
+Consts.rsun=695700e3 #m, nominal solar radius, source: 
+Consts.rjupiter=71492e3 #m, equatorial radius, source: 
+Consts.rsaturn=60268e3 #m, equatorial radius, source: 
+
+#For compatibility purposes with legacy: remove when legacy is retired
+RAD=Consts.rad
+DEG=Consts.deg
 
 
