@@ -19,16 +19,16 @@
 # # Pryngles module: rings
 
 from pryngles import *
+sci=Science
 
 # ## External modules
 
 import spiceypy as spy
-import math
-import numpy
-#mh=numpy
-mh=math
+import math as mh
+import numpy as np
+import copy
 
-# ## Ring Class
+# ## Ring default properties
 
 class RingDefaults(object):
     """
@@ -44,26 +44,41 @@ class RingDefaults(object):
         
     physics:
     
-        fi: float [adimensional], default = 1
+        fi: float [adimensional], default = 1:
             Fraction of the radius of the primary object where ring stars.
             
-        fe: float [adimensional], default = 1
+        fe: float [adimensional], default = 1:
             Fraction of the radius of the primary object where ring ends.
             
-        i: float [radians], default = 0
-            Inclination of the ring with respect to the equator of the primary
-            object.
+        i: float [radians], default = 0:
+            Inclination of the ring with respect to the ecliptic plane.
+            
+        roll: float [radians], default = 0:
+            Roll angle.  This is the angle with respect to ecliptic x-axis in which 
+            the normal to the ring plane is rotated.
             
     optics:
     
-        nspangles: int, default = 1000
+        nspangles: int, default = 1000: 
             Number of spangles on which the object will be discretized.
+            
+        albedo_gray_normal: float. default = 1: 
+            Lambertian (normal) gray (wavelength indpendent) albedo of the spangle.
+            
+        tau_gray_optical: float. default = 0:
+            Gray (wavelength indpendent) Optical depth of the spangle.  
+            If 0 the spangle is entirely opaque to all wavelength, despite its type.            
     """
     orbit=dict()
     
-    physics=dict(fi=1.0,fe=2.0,i=0.0)
+    physics=dict(fi=1.0,fe=2.0,i=0.0,roll=0.0)
     
-    optics=dict(nspangles=1000)
+    optics=dict(nspangles=1000,
+                albedo_gray_normal=1,
+                tau_gray_optical=0
+               )
+
+# ## Ring Class
 
 BODY_KINDS+=["Ring"]
 
@@ -74,11 +89,14 @@ class Ring(Body):
     
     Additional public attributes:
     
-        physics.ri: float [rebound length unit]
+        ri: float [rlu]:
             Radius of the inner border of the ring
 
-        physics.re: float [rebound length unit]
+        re: float [rlu]:
             Radius of the outer border of the ring
+            
+        spangles: list of Spangle objects:
+            List of spangles covering the surface (for spangle options see Spangle documentation)
     
     Override methods:
     
@@ -99,35 +117,20 @@ class Ring(Body):
         #Check primary
         if self.primary is None:
             raise ValueError(f"Primary not provided and mandatory for {self.kind}.")
-        #self.primary=primary
-        #self.primary._update_childs(self)
-        #self._update_parent(self.primary)
         
         #Update properties
         self.update_body(**self.__dict__)
-        
-    def update_body(self,**pars):
-        Body.update_body(self,**pars)
-        
-        #Here place the commands to update this kind of body
-        self.physics.ri=self.physics.fi*self.primary.physics.radius
-        self.physics.re=self.physics.fe*self.primary.physics.radius
-        
-        #Set transformation matrices
-        self._set_transform()
-        
-    def _set_transform(self):
-        """
-        Set transformation matrices
-        """
-        #Normal vector to ring
-        self.nr_ecl=np.array([0,mh.sin(self.physics.i),mh.cos(self.physics.i)]) 
-        self.nr_equ=np.array([0,0,1]) 
-        #Build transformation matrices
-        ex_equ=np.array([1,0,0]) 
-        ey_equ=np.array([0,mh.cos(self.physics.i),-mh.sin(self.physics.i)])
-        ez_equ=self.nr_ecl
-        self.M_equ2ecl=np.array(list(np.vstack((ex_equ,ey_equ,ez_equ)).transpose())).reshape((3,3))
-        self.M_ecl2equ=spy.invert(self.M_equ2ecl)
+
+
+# ### Update body
+
+def update_body(self,**pars):
+    Body.update_body(self,**pars)
+
+    #Here place the commands to update this kind of body
+    self.ri=self.physics.fi*self.primary.physics.radius
+    self.re=self.physics.fe*self.primary.physics.radius
+
+Ring.update_body=update_body
 
 
