@@ -17,16 +17,16 @@ import unittest
 from pryngles import *
 class Test(unittest.TestCase):
     def test_fun(self):
+        
+        #Get path
         filepath=Misc.get_data("diffuse_reflection_function.data")
         print(filepath)
-        """
-        self.assertEqual(os.path.exists(filename),False)
-        self.assertEqual(np.isclose([P.physics.wrot],
-                                    [2*np.pi/PlanetDefaults.physics["prot"]],
-                                    rtol=1e-7),
-                         [True]*1)
-        self.assertRaises(AssertionError,lambda:Observer(primary="Nada"))
-        """
+        
+        #print_df dataframe
+        import pandas as pd
+        import numpy as np
+        df=pd.DataFrame(np.zeros((5,3)),columns=["a","b","c"])
+        Misc.print_df(df)
         
 
 if __name__=="__main__":
